{ namespace, lib, ... }:
let
  inherit (lib.${namespace}) enabled;
in
{
  imports = [
    ./hardware-configuration.nix
  ];

  # System Config
  reichard = {
    nix = enabled;

    system = {
      boot = {
        enable = true;
        showNotch = true;
      };
      networking = {
        enable = true;
        enableIWD = true;
      };
    };

    hardware = {
      opengl = enabled;
      asahi = {
        enable = true;
        enableGPU = true;
        firmwareDirectory = ./firmware;
      };
    };

    security = {
      sops = {
        enable = true;
        # sshKeyPaths = [ "/etc/ssh/ssh_host_ed25519_key" ];
        defaultSopsFile = lib.snowfall.fs.get-file "secrets/lin-mbp-personal/default.yaml";
      };
    };

    programs = {
      graphical = {
        wms.hyprland = enabled;
      };
    };
  };

  # Hardware Config
  hardware = {
    bluetooth.enable = true;
    bluetooth.powerOnBoot = true;
  };

  time.timeZone = "America/New_York";
  system.stateVersion = "24.11";
}
