{ namespace, config, pkgs, lib, ... }:
let
  inherit (lib.${namespace}) enabled;

  cfg = config.${namespace}.user;
in
{
  reichard = {
    system = {
      boot = {
        enable = true;
        xenGuest = true;
      };
      disk = {
        enable = true;
        diskPath = "/dev/xvda";
      };
      networking = enabled; # TODO - Network Config
    };

    services = {
      openssh = {
        enable = true;
        authorizedKeys = [
          # MBP-Personal NixOS
          "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAILJJoyXQOv9cAjGUHrUcvsW7vY9W0PmuPMQSI9AMZvNY"
          # NixOS Builder
          "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIDF8QjeN8lpT+Mc70zwEJQqN9W/GKvTOTd32VgfNhVdN"
        ];
      };
    };
  };

  users.users.${cfg.name} = {
    openssh = {
      authorizedKeys.keys = [
        # MBP-Personal NixOS
        "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAILJJoyXQOv9cAjGUHrUcvsW7vY9W0PmuPMQSI9AMZvNY"
        # NixOS Builder
        "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIDF8QjeN8lpT+Mc70zwEJQqN9W/GKvTOTd32VgfNhVdN"
      ];
    };
  };

  networking = {
    defaultGateway = {
      address = "10.0.50.254";
      interface = "enX0";
    };
    interfaces.enX0.ipv4.addresses = [{
      address = "10.0.50.130";
      prefixLength = 24;
    }];
  };

  # System Packages
  environment.systemPackages = with pkgs; [
    htop
    tmux
    vim
  ];

  time.timeZone = "America/New_York";
  system.stateVersion = "24.11";
}
